% Lec2_example_Cuu
%
% visualizes the auto-covariance for several signals
%
% Alfred C. Schouten
% February 16, 2011
clear all
close all
clc

% default values and time vector
dt=0.01;        % sample frequency [s]
N=5000;         % # of samples
t=(0:N-1).'*dt; % time vector
maxlag=round(2/dt); % show only 2 seconds

%% A) white noise signal
u1=randn(N,1);  % input signal
[Cu1,lags]=xcov(u1,maxlag,'biased');
tau=lags*dt;    % convert <lags> in samples to <tau> in seconds

figure
subplot(211),plot(t,u1),ylabel('signal'),xlabel('time [s]')
box off
title('white noise')
pause
subplot(212),plot(tau,Cu1),ylabel('C_{uu}'),xlabel('tau [s]')
box off
drawnow
pause

%% B) low-pass filtered noise
f_low=2;         % cut-off frequency [Hz]
[b,a]=butter(2,2*pi*f_low,'s'); % butterworth filter, 2nd order
sys=tf(b,a);
u2=lsim(sys,u1,t);% simulate system
[Cu2]=xcov(u2,maxlag,'biased');

figure
subplot(211),plot(t,u2),ylabel('signal'),xlabel('time [s]')
title('low-pass filtered noise')
pause
subplot(212),plot(tau,Cu2),ylabel('C_{uu}'),xlabel('tau [s]')
drawnow
pause

%% C) sinusoid
fr=1;           % [Hz]
u3=cos(2*pi*fr*t);
[Cu3]=xcov(u3,maxlag,'biased');

figure
subplot(211),plot(t,u3),ylabel('signal'),xlabel('time [s]')
title('sinusoid')
pause
subplot(212),plot(tau,Cu3),ylabel('C_{uu}'),xlabel('tau [s]')
drawnow
pause

%% D) sinusoid with additional noise
n=1*randn(N,1);% additional (output-)noise
u4=u3+n;          % sinusoid with noise
[Cu4]=xcov(u4,maxlag,'biased');
figure
subplot(211),plot(t,u4),ylabel('signal'),xlabel('time [s]')
title('sinusoid with noise')
pause
subplot(212),plot(tau,Cu4),ylabel('C_{uu}'),xlabel('tau [s]')
pause

%% all in one figure for the lecture

if 1
    figure
    subplot(421),plot(t,u1,'linewidth',2),xlim([0 5]),box off,ylabel('white'),title('signal')
    subplot(422),plot(tau,Cu1,'linewidth',2),box off,title('C_{uu}')
    subplot(423),plot(t,u2,'linewidth',2),xlim([0 5]),box off,ylabel('low-pass ')
    subplot(424),plot(tau,Cu2,'linewidth',2),box off
    subplot(425),plot(t,u3,'linewidth',2),xlim([0 5]),box off,ylabel('sinusoid')
    subplot(426),plot(tau,Cu3,'linewidth',2),box off
    subplot(427),plot(t,u4,'linewidth',2),xlim([0 5]),box off,ylabel('sin. + noise'),xlabel('time [s]')
    subplot(428),plot(tau,Cu4,'linewidth',2),box off,xlabel('tau [s]')
end