% Lec2_example_Cuy_delay
%
% visualizes the auto-covariance for system with time-delay for several
% signals
%
% Alfred C. Schouten
% February 16, 2011
clear all
close all
clc

% default values and time vector
dt=0.01;        % sample frequency
N=5000;         % # of samples
t=(0:N-1).'*dt; % time vector
maxlag=round(2/dt);

%% A) white noise and time-delay
u1=randn(N,1);  % input signal
Ndelay=50;      % # samples delay
y1=[zeros(Ndelay,1);u1(1:end-Ndelay)];
[Cuy1,lags]=xcov(y1,u1,maxlag,'biased'); 
% note the order of u and y!
% the definition within Matlab and Westwick-Kearney is different
tau=lags*dt;    % convert <lags> in samples to <tau> in seconds

figure
subplot(311),plot(t,u1),ylabel('u(t)'),xlabel('time [s]')
box off
subplot(312),plot(t,y1),ylabel('y(t)'),xlabel('time [s]')
box off
pause
subplot(313),plot(tau,Cuy1),ylabel('C_{uy}(\tau)'),xlabel('\tau [s]')
box off
drawnow
pause

%% B) low-pass filtered noise
f_low=2;         % cut-off frequency [Hz]
[b,a]=butter(2,2*pi*f_low,'s'); % butterworth filter, 2nd order 
sys=tf(b,a);
u2=lsim(sys,u1,t);% simulate system, generates filtered input signal
y2=[zeros(Ndelay,1);u2(1:end-Ndelay)]; % simple delay!
[Cuy2,lags]=xcov(y2,u2,maxlag,'biased'); 
tau=lags*dt;    % convert <lags> in samples to <tau> in seconds

figure
subplot(311),plot(t,u2),ylabel('u(t)'),xlabel('time [s]')
box off
subplot(312),plot(t,y2),ylabel('y(t)'),xlabel('time [s]')
box off
pause
subplot(313),plot(tau,Cuy2),ylabel('C_{uy}(\tau)'),xlabel('\tau [s]')
drawnow

